diff --git a/core/modules/comment/src/Tests/CommentFieldsTest.php b/core/modules/comment/src/Tests/CommentFieldsTest.php
index 77cbbc0..73da1dc 100644
--- a/core/modules/comment/src/Tests/CommentFieldsTest.php
+++ b/core/modules/comment/src/Tests/CommentFieldsTest.php
@@ -114,7 +114,7 @@ public function testCommentFieldCreate() {
 
     // Try to save the comment field without selecting a comment type.
     $edit = array();
-    $this->drupalPostForm('admin/config/people/accounts/fields/user.user.field_user_comment/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm('admin/config/people/accounts/fields/user.user.field_user_comment/storage', $edit, t('Save field storage settings'));
     // We should get an error message.
     $this->assertText(t('An illegal choice has been detected. Please contact the site administrator.'));
 
@@ -131,7 +131,7 @@ public function testCommentFieldCreate() {
     $edit = array(
       'settings[comment_type]' => 'user_comment_type',
     );
-    $this->drupalPostForm('admin/config/people/accounts/fields/user.user.field_user_comment/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm('admin/config/people/accounts/fields/user.user.field_user_comment/storage', $edit, t('Save field storage settings'));
     // We shouldn't get an error message.
     $this->assertNoText(t('An illegal choice has been detected. Please contact the site administrator.'));
   }
diff --git a/core/modules/comment/src/Tests/CommentNonNodeTest.php b/core/modules/comment/src/Tests/CommentNonNodeTest.php
index 8d8e38b..bbafbc0 100644
--- a/core/modules/comment/src/Tests/CommentNonNodeTest.php
+++ b/core/modules/comment/src/Tests/CommentNonNodeTest.php
@@ -398,7 +398,7 @@ function testCommentFunctionality() {
       'default_value_input[comment][0][status]' => CommentItemInterface::CLOSED,
       'settings[anonymous]' => COMMENT_ANONYMOUS_MAY_CONTACT,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     $this->drupalGet('entity_test/structure/entity_test/fields/entity_test.entity_test.comment');
     $this->assertNoFieldChecked('edit-default-value-input-comment-0-status-0');
     $this->assertFieldChecked('edit-default-value-input-comment-0-status-1');
diff --git a/core/modules/content_translation/src/Tests/ContentTranslationSettingsTest.php b/core/modules/content_translation/src/Tests/ContentTranslationSettingsTest.php
index f1ddd4a..43d8ae8 100644
--- a/core/modules/content_translation/src/Tests/ContentTranslationSettingsTest.php
+++ b/core/modules/content_translation/src/Tests/ContentTranslationSettingsTest.php
@@ -175,7 +175,7 @@ function testSettingsUI() {
       // Test that also the Field UI form behaves correctly.
       $translatable = !$translatable;
       $edit = array('translatable' => $translatable);
-      $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.body', $edit, t('Save settings'));
+      $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.body', $edit, t('Save field settings'));
       \Drupal::entityManager()->clearCachedFieldDefinitions();
       $field = FieldConfig::loadByName('node', 'article', 'body');
       $definitions = \Drupal::entityManager()->getFieldDefinitions('node', 'article');
diff --git a/core/modules/content_translation/src/Tests/ContentTranslationSyncImageTest.php b/core/modules/content_translation/src/Tests/ContentTranslationSyncImageTest.php
index 606b5b3..5422d4c 100644
--- a/core/modules/content_translation/src/Tests/ContentTranslationSyncImageTest.php
+++ b/core/modules/content_translation/src/Tests/ContentTranslationSyncImageTest.php
@@ -94,7 +94,7 @@ function testImageFieldSync() {
       'third_party_settings[content_translation][translation_sync][alt]' => FALSE,
       'third_party_settings[content_translation][translation_sync][title]' => FALSE,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
 
     // Check that the content translation settings page reflects the changes
     // performed in the field edit page.
diff --git a/core/modules/datetime/src/Tests/DateTimeFieldTest.php b/core/modules/datetime/src/Tests/DateTimeFieldTest.php
index 69f3725..f421bde 100644
--- a/core/modules/datetime/src/Tests/DateTimeFieldTest.php
+++ b/core/modules/datetime/src/Tests/DateTimeFieldTest.php
@@ -626,7 +626,7 @@ function testDefaultValue() {
     $field_edit = array(
       'default_value_input[default_date_type]' => 'now',
     );
-    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save field settings'));
 
     // Check that default value is selected in default value form.
     $this->drupalGet('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name);
@@ -650,7 +650,7 @@ function testDefaultValue() {
       'default_value_input[default_date_type]' => 'relative',
       'default_value_input[default_date]' => 'invalid date',
     );
-    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save field settings'));
 
     $this->assertText('The relative date value entered is invalid.');
 
@@ -659,7 +659,7 @@ function testDefaultValue() {
       'default_value_input[default_date_type]' => 'relative',
       'default_value_input[default_date]' => '+90 days',
     );
-    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save field settings'));
 
     // Check that default value is selected in default value form.
     $this->drupalGet('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name);
@@ -682,7 +682,7 @@ function testDefaultValue() {
     $field_edit = array(
       'default_value_input[default_date_type]' => '',
     );
-    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name, $field_edit, t('Save field settings'));
 
     // Check that default value is selected in default value form.
     $this->drupalGet('admin/structure/types/manage/date_content/fields/node.date_content.' . $field_name);
diff --git a/core/modules/entity_reference/src/Tests/EntityReferenceAdminTest.php b/core/modules/entity_reference/src/Tests/EntityReferenceAdminTest.php
index 075ce33..cae9a84 100644
--- a/core/modules/entity_reference/src/Tests/EntityReferenceAdminTest.php
+++ b/core/modules/entity_reference/src/Tests/EntityReferenceAdminTest.php
@@ -90,7 +90,7 @@ public function testFieldAdminHandler() {
     $this->assertFieldSelectOptions('settings[target_type]', array_keys(\Drupal::entityManager()->getDefinitions()));
 
     // Second step: 'Field settings' form.
-    $this->drupalPostForm(NULL, array(), t('Save field settings'));
+    $this->drupalPostForm(NULL, array(), t('Save field storage settings'));
 
     // The base handler should be selected by default.
     $this->assertFieldByName('settings[handler]', 'default:node');
@@ -127,16 +127,16 @@ public function testFieldAdminHandler() {
     $this->drupalPostForm(NULL, array(
       'required' => '1',
       'settings[handler_settings][target_bundles][' . key($bundles) . ']' => key($bundles),
-    ), t('Save settings'));
+    ), t('Save field settings'));
 
     // Check that the field appears in the overview form.
     $this->assertFieldByXPath('//table[@id="field-overview"]//tr[@id="field-test"]/td[1]', 'Test label', 'Field was created and appears in the overview page.');
 
     // Check that the field settings form can be submitted again, even when the
     // field is required.
-    // The first 'Edit' link is for the Body field.
-    $this->clickLink(t('Edit'), 1);
-    $this->drupalPostForm(NULL, array(), t('Save settings'));
+    // The first 'Field settings' link is for the Body field.
+    $this->clickLink(t('Field settings'), 1);
+    $this->drupalPostForm(NULL, array(), t('Save field settings'));
 
     // Switch the target type to 'taxonomy_term' and check that the settings
     // specific to its selection handler are displayed.
@@ -144,7 +144,7 @@ public function testFieldAdminHandler() {
     $edit = array(
       'settings[target_type]' => 'taxonomy_term',
     );
-    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field storage settings'));
     $this->drupalGet($bundle_path . '/fields/' . $field_name);
     $this->assertFieldByName('settings[handler_settings][auto_create]');
 
@@ -154,7 +154,7 @@ public function testFieldAdminHandler() {
     $edit = array(
       'settings[target_type]' => 'user',
     );
-    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field storage settings'));
     $this->drupalGet($bundle_path . '/fields/' . $field_name);
     $this->assertFieldByName('settings[handler_settings][filter][type]', '_none');
 
@@ -163,7 +163,7 @@ public function testFieldAdminHandler() {
     $edit = array(
       'settings[target_type]' => 'node',
     );
-    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field storage settings'));
 
     // Try to select the views handler.
     $edit = array(
@@ -174,7 +174,7 @@ public function testFieldAdminHandler() {
       ':create' => \Drupal::url('views_ui.add'),
       ':existing' => \Drupal::url('entity.view.collection'),
     )));
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     // If no eligible view is available we should see a message.
     $this->assertText('The views entity selection mode requires a view.');
 
@@ -186,14 +186,14 @@ public function testFieldAdminHandler() {
     $edit = array(
       'settings[handler_settings][view][view_and_display]' => 'test_entity_reference:entity_reference_1',
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     $this->assertResponse(200);
 
     // Switch the target type to 'entity_test'.
     $edit = array(
       'settings[target_type]' => 'entity_test',
     );
-    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm($bundle_path . '/fields/' . $field_name . '/storage', $edit, t('Save field storage settings'));
     $this->drupalGet($bundle_path . '/fields/' . $field_name);
     $edit = array(
       'settings[handler]' => 'views',
@@ -203,7 +203,7 @@ public function testFieldAdminHandler() {
       'required' => FALSE,
       'settings[handler_settings][view][view_and_display]' => 'test_entity_reference_entity_test:entity_reference_1',
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     $this->assertResponse(200);
 
     // Create a new view and display it as a entity reference.
@@ -235,7 +235,7 @@ public function testFieldAdminHandler() {
       'field_name' => $field_name,
     );
     $this->drupalPostForm($bundle_path . '/fields/add-field', $edit, t('Save and continue'));
-    $this->drupalPostForm(NULL, array(), t('Save field settings'));
+    $this->drupalPostForm(NULL, array(), t('Save field storage settings'));
 
     // Add the view to the test field.
     $edit = array(
@@ -246,7 +246,7 @@ public function testFieldAdminHandler() {
       'required' => FALSE,
       'settings[handler_settings][view][view_and_display]' => 'node_test_view:entity_reference_1',
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
 
     // Create nodes.
     $node1 = Node::create([
diff --git a/core/modules/entity_reference/src/Tests/EntityReferenceFieldDefaultValueTest.php b/core/modules/entity_reference/src/Tests/EntityReferenceFieldDefaultValueTest.php
index c2ceed9..c6676f1 100644
--- a/core/modules/entity_reference/src/Tests/EntityReferenceFieldDefaultValueTest.php
+++ b/core/modules/entity_reference/src/Tests/EntityReferenceFieldDefaultValueTest.php
@@ -78,7 +78,7 @@ function testEntityReferenceDefaultValue() {
     $field_edit = array(
       'default_value_input[' . $field_name . '][0][target_id]' => $referenced_node->getTitle() . ' (' .$referenced_node->id() . ')',
     );
-    $this->drupalPostForm('admin/structure/types/manage/reference_content/fields/node.reference_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/reference_content/fields/node.reference_content.' . $field_name, $field_edit, t('Save field settings'));
 
     // Check that default value is selected in default value form.
     $this->drupalGet('admin/structure/types/manage/reference_content/fields/node.reference_content.' . $field_name);
@@ -142,7 +142,7 @@ function testEntityReferenceDefaultConfigValue() {
       'default_value_input[' . $field_name . '][0][target_id]' => $referenced_node_type->label() . ' (' .$referenced_node_type->id() . ')',
       'default_value_input[' . $field_name . '][1][target_id]' => $referenced_node_type2->label() . ' (' .$referenced_node_type2->id() . ')',
     );
-    $this->drupalPostForm('admin/structure/types/manage/reference_content/fields/node.reference_content.' . $field_name, $field_edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/reference_content/fields/node.reference_content.' . $field_name, $field_edit, t('Save field settings'));
 
     // Check that the field has a dependency on the default value.
     $config_entity = $this->config('field.field.node.reference_content.' . $field_name)->get();
diff --git a/core/modules/entity_reference/src/Tests/EntityReferenceIntegrationTest.php b/core/modules/entity_reference/src/Tests/EntityReferenceIntegrationTest.php
index c059848..21835fb 100644
--- a/core/modules/entity_reference/src/Tests/EntityReferenceIntegrationTest.php
+++ b/core/modules/entity_reference/src/Tests/EntityReferenceIntegrationTest.php
@@ -148,7 +148,7 @@ public function testSupportedEntityTypesAndWidgets() {
       if ($key == 'content') {
         $field_edit['settings[handler_settings][target_bundles][' . $referenced_entities[0]->getEntityTypeId() . ']'] = TRUE;
       }
-      $this->drupalPostForm($this->entityType . '/structure/' . $this->bundle .'/fields/' . $this->entityType . '.' . $this->bundle . '.' . $this->fieldName, $field_edit, t('Save settings'));
+      $this->drupalPostForm($this->entityType . '/structure/' . $this->bundle .'/fields/' . $this->entityType . '.' . $this->bundle . '.' . $this->fieldName, $field_edit, t('Save field settings'));
       // Ensure the configuration has the expected dependency on the entity that
       // is being used a default value.
       $field = FieldConfig::loadByName($this->entityType, $this->bundle, $this->fieldName);
diff --git a/core/modules/field/src/Tests/Boolean/BooleanFieldTest.php b/core/modules/field/src/Tests/Boolean/BooleanFieldTest.php
index 31f2c05..8bba0d0 100644
--- a/core/modules/field/src/Tests/Boolean/BooleanFieldTest.php
+++ b/core/modules/field/src/Tests/Boolean/BooleanFieldTest.php
@@ -122,7 +122,7 @@ function testBooleanField() {
     $edit = array(
       'settings[on_label]' => $on,
     );
-    $this->drupalPostForm('entity_test/structure/entity_test/fields/entity_test.entity_test.' . $field_name, $edit, t('Save settings'));
+    $this->drupalPostForm('entity_test/structure/entity_test/fields/entity_test.entity_test.' . $field_name, $edit, t('Save field settings'));
     // Check if we see the updated labels in the creation form.
     $this->drupalGet('entity_test/add');
     $this->assertRaw($on);
diff --git a/core/modules/field/src/Tests/Boolean/BooleanFormatterSettingsTest.php b/core/modules/field/src/Tests/Boolean/BooleanFormatterSettingsTest.php
index e9b693d..e972013 100644
--- a/core/modules/field/src/Tests/Boolean/BooleanFormatterSettingsTest.php
+++ b/core/modules/field/src/Tests/Boolean/BooleanFormatterSettingsTest.php
@@ -115,7 +115,7 @@ function testBooleanFormatterSettings() {
       $this->drupalPostForm(NULL, array(
         'settings[on_label]' => $values[0],
         'settings[off_label]' => $values[1],
-      ), 'Save settings');
+      ), 'Save field settings');
 
       // Open the Manage Display page and trigger the field settings form.
       $this->drupalGet('admin/structure/types/manage/' . $this->bundle . '/display');
diff --git a/core/modules/field/src/Tests/Number/NumberFieldTest.php b/core/modules/field/src/Tests/Number/NumberFieldTest.php
index e4f104e..6f1b5be 100644
--- a/core/modules/field/src/Tests/Number/NumberFieldTest.php
+++ b/core/modules/field/src/Tests/Number/NumberFieldTest.php
@@ -547,7 +547,7 @@ function assertSetMinimumValue($field, $minimum_value) {
     $edit = array(
       'settings[min]' => $minimum_value,
     );
-    $this->drupalPostForm($field_configuration_url, $edit, t('Save settings'));
+    $this->drupalPostForm($field_configuration_url, $edit, t('Save field settings'));
     // Check if an error message is shown.
     $this->assertNoRaw(t('%name is not a valid number.', array('%name' => t('Minimum'))), 'Saved ' . gettype($minimum_value) .'  value as minimal value on a ' . $field->getType() . ' field');
     // Check if a success message is shown.
diff --git a/core/modules/field_ui/src/FieldConfigListBuilder.php b/core/modules/field_ui/src/FieldConfigListBuilder.php
index 1dd2c7c..683e315 100644
--- a/core/modules/field_ui/src/FieldConfigListBuilder.php
+++ b/core/modules/field_ui/src/FieldConfigListBuilder.php
@@ -163,9 +163,10 @@ public function getDefaultOperations(EntityInterface $entity) {
 
     if ($entity->access('update') && $entity->hasLinkTemplate("{$entity->getTargetEntityTypeId()}-field-edit-form")) {
       $operations['edit'] = array(
-        'title' => $this->t('Edit'),
+        'title' => $this->t('Field settings'),
         'weight' => 10,
         'url' => $entity->urlInfo("{$entity->getTargetEntityTypeId()}-field-edit-form"),
+        'attributes' => array('title' => $this->t('Edit field settings.')),
       );
     }
     if ($entity->access('delete') && $entity->hasLinkTemplate("{$entity->getTargetEntityTypeId()}-field-delete-form")) {
@@ -173,17 +174,16 @@ public function getDefaultOperations(EntityInterface $entity) {
         'title' => $this->t('Delete'),
         'weight' => 100,
         'url' => $entity->urlInfo("{$entity->getTargetEntityTypeId()}-field-delete-form"),
+        'attributes' => array('title' => $this->t('Delete field.')),
       );
     }
 
     $operations['storage-settings'] = array(
       'title' => $this->t('Storage settings'),
       'weight' => 20,
-      'attributes' => array('title' => $this->t('Edit storage settings.')),
+      'attributes' => array('title' => $this->t('Edit field storage settings.')),
       'url' => $entity->urlInfo("{$entity->getTargetEntityTypeId()}-storage-edit-form"),
     );
-    $operations['edit']['attributes']['title'] = $this->t('Edit field settings.');
-    $operations['delete']['attributes']['title'] = $this->t('Delete field.');
 
     return $operations;
   }
diff --git a/core/modules/field_ui/src/Form/FieldConfigEditForm.php b/core/modules/field_ui/src/Form/FieldConfigEditForm.php
index ba972a9..c309cc9 100644
--- a/core/modules/field_ui/src/Form/FieldConfigEditForm.php
+++ b/core/modules/field_ui/src/Form/FieldConfigEditForm.php
@@ -119,7 +119,7 @@ public function form(array $form, FormStateInterface $form_state) {
    */
   protected function actions(array $form, FormStateInterface $form_state) {
     $actions = parent::actions($form, $form_state);
-    $actions['submit']['#value'] = $this->t('Save settings');
+    $actions['submit']['#value'] = $this->t('Save field settings');
 
     if (!$this->entity->isNew()) {
       $target_entity_type = $this->entityManager->getDefinition($this->entity->getTargetEntityTypeId());
diff --git a/core/modules/field_ui/src/Form/FieldStorageConfigEditForm.php b/core/modules/field_ui/src/Form/FieldStorageConfigEditForm.php
index adafcc7..1b684c4 100644
--- a/core/modules/field_ui/src/Form/FieldStorageConfigEditForm.php
+++ b/core/modules/field_ui/src/Form/FieldStorageConfigEditForm.php
@@ -68,7 +68,7 @@ public function form(array $form, FormStateInterface $form_state) {
     // See if data already exists for this field.
     // If so, prevent changes to the field settings.
     if ($this->entity->hasData()) {
-      $form['#prefix'] = '<div class="messages messages--error">' . $this->t('There is data for this field in the database. The field settings can no longer be changed.') . '</div>' . $form['#prefix'];
+      $form['#prefix'] = '<div class="messages messages--error">' . $this->t('There is data for this field in the database. The field storage settings can no longer be changed.') . '</div>' . $form['#prefix'];
     }
 
     // Add settings provided by the field module. The field module is
@@ -138,7 +138,7 @@ public function form(array $form, FormStateInterface $form_state) {
    */
   protected function actions(array $form, FormStateInterface $form_state) {
     $elements = parent::actions($form, $form_state);
-    $elements['submit']['#value'] = $this->t('Save field settings');
+    $elements['submit']['#value'] = $this->t('Save field storage settings');
 
     return $elements;
   }
diff --git a/core/modules/field_ui/src/Tests/FieldUiTestTrait.php b/core/modules/field_ui/src/Tests/FieldUiTestTrait.php
index ec0e326..8208264 100644
--- a/core/modules/field_ui/src/Tests/FieldUiTestTrait.php
+++ b/core/modules/field_ui/src/Tests/FieldUiTestTrait.php
@@ -52,11 +52,11 @@ public function fieldUIAddNewField($bundle_path, $field_name, $label = NULL, $fi
     $this->assertLink($label, 0, 'Field label is correct in the breadcrumb of the storage settings page.');
 
     // Second step: 'Storage settings' form.
-    $this->drupalPostForm(NULL, $storage_edit, t('Save field settings'));
+    $this->drupalPostForm(NULL, $storage_edit, t('Save field storage settings'));
     $this->assertRaw(t('Updated field %label field settings.', array('%label' => $label)), 'Redirected to field settings page.');
 
     // Third step: 'Field settings' form.
-    $this->drupalPostForm(NULL, $field_edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $field_edit, t('Save field settings'));
     $this->assertRaw(t('Saved %label configuration.', array('%label' => $label)), 'Redirected to "Manage fields" page.');
 
     // Check that the field appears in the overview form.
@@ -94,7 +94,7 @@ public function fieldUIAddExistingField($bundle_path, $existing_storage_name, $l
     $this->assertNoRaw('&amp;lt;', 'The page does not have double escaped HTML tags.');
 
     // Second step: 'Field settings' form.
-    $this->drupalPostForm(NULL, $field_edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $field_edit, t('Save field settings'));
     $this->assertRaw(t('Saved %label configuration.', array('%label' => $label)), 'Redirected to "Manage fields" page.');
 
     // Check that the field appears in the overview form.
diff --git a/core/modules/field_ui/src/Tests/ManageFieldsTest.php b/core/modules/field_ui/src/Tests/ManageFieldsTest.php
index f1db4d4..f8f2043 100644
--- a/core/modules/field_ui/src/Tests/ManageFieldsTest.php
+++ b/core/modules/field_ui/src/Tests/ManageFieldsTest.php
@@ -162,7 +162,7 @@ function manageFieldsPage($type = '') {
           $this->assertIdentical($url, (string) $link['href']);
           $number_of_links_found++;
           break;
-        case 'Edit storage settings.':
+        case 'Edit field storage settings.':
           $this->assertIdentical("$url/storage", (string) $link['href']);
           $number_of_links_found++;
           break;
@@ -201,7 +201,7 @@ function updateField() {
     $edit = array(
       'settings[test_field_storage_setting]' => $string,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field storage settings'));
 
     // Go to the field edit page.
     $this->drupalGet('admin/structure/types/manage/' . $this->contentType . '/fields/' . $field_id);
@@ -209,7 +209,7 @@ function updateField() {
       'settings[test_field_setting]' => $string,
     );
     $this->assertText(t('Default value'), 'Default value heading is shown');
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
 
     // Assert the field settings are correct.
     $this->assertFieldSettings($this->contentType, $this->fieldName, $string);
@@ -251,7 +251,7 @@ function cardinalitySettings() {
       'cardinality' => 'number',
       'cardinality_number' => '',
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPostForm($field_edit_path, $edit, t('Save field storage settings'));
     $this->assertText('Number of values is required.');
 
     // Submit a custom number.
@@ -259,23 +259,23 @@ function cardinalitySettings() {
       'cardinality' => 'number',
       'cardinality_number' => 6,
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPostForm($field_edit_path, $edit, t('Save field storage settings'));
     $this->assertText('Updated field Body field settings.');
     $this->drupalGet($field_edit_path);
     $this->assertFieldByXPath("//select[@name='cardinality']", 'number');
     $this->assertFieldByXPath("//input[@name='cardinality_number']", 6);
 
     // Check that tabs displayed.
-    $this->assertLink(t('Edit'));
-    $this->assertLinkByHref('admin/structure/types/manage/article/fields/node.article.body');
     $this->assertLink(t('Field settings'));
+    $this->assertLinkByHref('admin/structure/types/manage/article/fields/node.article.body');
+    $this->assertLink(t('Field storage settings'));
     $this->assertLinkByHref($field_edit_path);
 
     // Set to unlimited.
     $edit = array(
       'cardinality' => FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
     );
-    $this->drupalPostForm($field_edit_path, $edit, t('Save field settings'));
+    $this->drupalPostForm($field_edit_path, $edit, t('Save field storage settings'));
     $this->assertText('Updated field Body field settings.');
     $this->drupalGet($field_edit_path);
     $this->assertFieldByXPath("//select[@name='cardinality']", FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED);
@@ -395,12 +395,12 @@ function testDefaultValue() {
 
     // Check that invalid default values are rejected.
     $edit = array($element_name => '-1');
-    $this->drupalPostForm($admin_path, $edit, t('Save settings'));
+    $this->drupalPostForm($admin_path, $edit, t('Save field settings'));
     $this->assertText("$field_name does not accept the value -1", 'Form validation failed.');
 
     // Check that the default value is saved.
     $edit = array($element_name => '1');
-    $this->drupalPostForm($admin_path, $edit, t('Save settings'));
+    $this->drupalPostForm($admin_path, $edit, t('Save field settings'));
     $this->assertText("Saved $field_name configuration", 'The form was successfully submitted.');
     $field = FieldConfig::loadByName('node', $this->contentType, $field_name);
     $this->assertEqual($field->getDefaultValueLiteral(), array(array('value' => 1)), 'The default value was correctly saved.');
@@ -411,7 +411,7 @@ function testDefaultValue() {
 
     // Check that the default value can be emptied.
     $edit = array($element_name => '');
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     $this->assertText("Saved $field_name configuration", 'The form was successfully submitted.');
     $field = FieldConfig::loadByName('node', $this->contentType, $field_name);
     $this->assertEqual($field->getDefaultValueLiteral(), NULL, 'The default value was correctly saved.');
@@ -426,10 +426,10 @@ function testDefaultValue() {
     $edit = array(
       'required' => 1,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
 
     $this->drupalGet($admin_path);
-    $this->drupalPostForm(NULL, array(), t('Save settings'));
+    $this->drupalPostForm(NULL, array(), t('Save field settings'));
     $this->assertText("Saved $field_name configuration", 'The form was successfully submitted.');
     $field = FieldConfig::loadByName('node', $this->contentType, $field_name);
     $this->assertEqual($field->getDefaultValueLiteral(), NULL, 'The default value was correctly saved.');
@@ -627,7 +627,7 @@ public function testExternalDestinations() {
     $options = [
       'query' => ['destinations' => ['http://example.com']],
     ];
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.body/storage', [], 'Save field settings', $options);
+    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.body/storage', [], 'Save field storage settings', $options);
     // The external redirect should not fire.
     $this->assertUrl('admin/structure/types/manage/article/fields/node.article.body/storage', $options);
     $this->assertResponse(200);
@@ -675,7 +675,7 @@ function testHelpDescriptions() {
     $edit = array(
       'description' => '<strong>Test with an upload field.',
     );
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.field_image', $edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.field_image', $edit, t('Save field settings'));
 
     // Check that hook_field_widget_form_alter() does believe this is the
     // default value form.
@@ -685,7 +685,7 @@ function testHelpDescriptions() {
     $edit = array(
       'description' => '<em>Test with a non upload field.',
     );
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.field_tags', $edit, t('Save settings'));
+    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.field_tags', $edit, t('Save field settings'));
 
     $this->drupalGet('node/add/article');
     $this->assertRaw('<strong>Test with an upload field.</strong>');
diff --git a/core/modules/file/src/Tests/FileFieldDisplayTest.php b/core/modules/file/src/Tests/FileFieldDisplayTest.php
index aa4923c..301c80c 100644
--- a/core/modules/file/src/Tests/FileFieldDisplayTest.php
+++ b/core/modules/file/src/Tests/FileFieldDisplayTest.php
@@ -150,13 +150,13 @@ function testDescToggle() {
       'label' => $this->randomString(),
     );
     $this->drupalPostForm('/admin/structure/types/manage/' . $type_name . '/fields/add-field', $edit, t('Save and continue'));
-    $this->drupalPostForm(NULL, array(), t('Save field settings'));
+    $this->drupalPostForm(NULL, array(), t('Save field storage settings'));
     // Ensure the description field is selected on the field instance settings
     // form. That's what this test is all about.
     $edit = array(
       'settings[description_field]' => TRUE,
     );
-    $this->drupalPostForm(NULL, $edit, t('Save settings'));
+    $this->drupalPostForm(NULL, $edit, t('Save field settings'));
     // Add a node of our new type and upload a file to it.
     $file = current($this->drupalGetTestFiles('text'));
     $title = $this->randomString();
diff --git a/core/modules/file/src/Tests/FileFieldWidgetTest.php b/core/modules/file/src/Tests/FileFieldWidgetTest.php
index e2f4aa2..c4114e0 100644
--- a/core/modules/file/src/Tests/FileFieldWidgetTest.php
+++ b/core/modules/file/src/Tests/FileFieldWidgetTest.php
@@ -281,7 +281,7 @@ function testPrivateFileSetting() {
 
     // Change the field setting to make its files private, and upload a file.
     $edit = array('settings[uri_scheme]' => 'private');
-    $this->drupalPostForm("admin/structure/types/manage/$type_name/fields/$field_id/storage", $edit, t('Save field settings'));
+    $this->drupalPostForm("admin/structure/types/manage/$type_name/fields/$field_id/storage", $edit, t('Save field storage settings'));
     $nid = $this->uploadNodeFile($test_file, $field_name, $type_name);
     $node_storage->resetCache(array($nid));
     $node = $node_storage->load($nid);
diff --git a/core/modules/image/src/Tests/ImageFieldDisplayTest.php b/core/modules/image/src/Tests/ImageFieldDisplayTest.php
index c4cf485..624a570 100644
--- a/core/modules/image/src/Tests/ImageFieldDisplayTest.php
+++ b/core/modules/image/src/Tests/ImageFieldDisplayTest.php
@@ -300,7 +300,7 @@ function testImageFieldSettings() {
     // 1, so we need to make sure the file widget prevents these notices by
     // providing all settings, even if they are not used.
     // @see FileWidget::formMultipleElements().
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.' . $field_name . '/storage', array('cardinality' => FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED), t('Save field settings'));
+    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.' . $field_name . '/storage', array('cardinality' => FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED), t('Save field storage settings'));
     $edit = array(
       'files[' . $field_name . '_1][]' => drupal_realpath($test_image->uri),
     );
@@ -350,7 +350,7 @@ function testImageFieldDefaultImage() {
       'settings[default_image][alt]' => $alt,
       'settings[default_image][title]' => $title,
     );
-    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/storage", $edit, t('Save field settings'));
+    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/storage", $edit, t('Save field storage settings'));
     // Clear field definition cache so the new default image is detected.
     \Drupal::entityManager()->clearCachedFieldDefinitions();
     $field_storage = FieldStorageConfig::loadByName('node', $field_name);
@@ -401,7 +401,7 @@ function testImageFieldDefaultImage() {
     $edit = array(
       'settings[default_image][uuid][fids]' => 0,
     );
-    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/storage", $edit, t('Save field settings'));
+    $this->drupalPostForm("admin/structure/types/manage/article/fields/node.article.$field_name/storage", $edit, t('Save field storage settings'));
     // Clear field definition cache so the new default image is detected.
     \Drupal::entityManager()->clearCachedFieldDefinitions();
     $field_storage = FieldStorageConfig::loadByName('node', $field_name);
@@ -417,7 +417,7 @@ function testImageFieldDefaultImage() {
       'settings[default_image][alt]' => $alt,
       'settings[default_image][title]' => $title,
     );
-    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.' . $private_field_name . '/storage', $edit, t('Save field settings'));
+    $this->drupalPostForm('admin/structure/types/manage/article/fields/node.article.' . $private_field_name . '/storage', $edit, t('Save field storage settings'));
     // Clear field definition cache so the new default image is detected.
     \Drupal::entityManager()->clearCachedFieldDefinitions();
 
diff --git a/core/modules/node/src/Tests/NodeAccessFieldTest.php b/core/modules/node/src/Tests/NodeAccessFieldTest.php
index ab490bb..f862e88 100644
--- a/core/modules/node/src/Tests/NodeAccessFieldTest.php
+++ b/core/modules/node/src/Tests/NodeAccessFieldTest.php
@@ -98,7 +98,7 @@ function testNodeAccessAdministerField() {
     $this->drupalPostForm(
       "admin/structure/types/manage/page/fields/node.page.{$this->fieldName}",
       $edit,
-      t('Save settings')
+      t('Save field settings')
     );
 
     // Log in as the administrator.
diff --git a/core/modules/options/src/Tests/OptionsFieldUITest.php b/core/modules/options/src/Tests/OptionsFieldUITest.php
index d4219c6..01b27a9 100644
--- a/core/modules/options/src/Tests/OptionsFieldUITest.php
+++ b/core/modules/options/src/Tests/OptionsFieldUITest.php
@@ -297,7 +297,7 @@ protected function createOptionsField($type) {
    */
   function assertAllowedValuesInput($input_string, $result, $message) {
     $edit = array('settings[allowed_values]' => $input_string);
-    $this->drupalPostForm($this->adminPath, $edit, t('Save field settings'));
+    $this->drupalPostForm($this->adminPath, $edit, t('Save field storage settings'));
     $this->assertNoRaw('&amp;lt;', 'The page does not have double escaped HTML tags.');
 
     if (is_string($result)) {
@@ -325,7 +325,7 @@ function testNodeDisplay() {
         0|$off",
     );
 
-    $this->drupalPostForm($this->adminPath, $edit, t('Save field settings'));
+    $this->drupalPostForm($this->adminPath, $edit, t('Save field storage settings'));
     $this->assertText(format_string('Updated field @field_name field settings.', array('@field_name' => $this->fieldName)), "The 'On' and 'Off' form fields work for boolean fields.");
 
     // Select a default value.
diff --git a/core/modules/options/src/Tests/OptionsFloatFieldImportTest.php b/core/modules/options/src/Tests/OptionsFloatFieldImportTest.php
index 5be5840..879f93f 100644
--- a/core/modules/options/src/Tests/OptionsFloatFieldImportTest.php
+++ b/core/modules/options/src/Tests/OptionsFloatFieldImportTest.php
@@ -53,7 +53,7 @@ public function testImport() {
 
     // Set the active to not use dots in the allowed values key names.
     $edit = array('settings[allowed_values]' => "0|Zero\n1|One");
-    $this->drupalPostForm($admin_path, $edit, t('Save field settings'));
+    $this->drupalPostForm($admin_path, $edit, t('Save field storage settings'));
     $field_storage = FieldStorageConfig::loadByName('node', $field_name);
     $this->assertIdentical($field_storage->getSetting('allowed_values'), $array = array('0' => 'Zero', '1' => 'One'));
 

diff --git a/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php b/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
index 6c869e5..ee95a28 100644
--- a/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
+++ b/core/modules/field_ui/src/Plugin/Derivative/FieldUiLocalTask.php
@@ -97,14 +97,14 @@ public function getDerivativeDefinitions($base_plugin_definition) {
         // Field edit tab.
         $this->derivatives["field_edit_$entity_type_id"] = array(
           'route_name' => "entity.field_config.{$entity_type_id}_field_edit_form",
-          'title' => $this->t('Edit'),
+          'title' => $this->t('Field settings'),
           'base_route' => "entity.field_config.{$entity_type_id}_field_edit_form",
         );
 
         // Field settings tab.
         $this->derivatives["field_storage_$entity_type_id"] = array(
           'route_name' => "entity.field_config.{$entity_type_id}_storage_edit_form",
-          'title' => $this->t('Field settings'),
+          'title' => $this->t('Field storage settings'),
           'base_route' => "entity.field_config.{$entity_type_id}_field_edit_form",
         );
 
@@ -97,14 +97,14 @@ public function getDerivativeDefinitions($base_plugin_definition) {
         );
 
-        // Field settings tab.
+        // Field storage settings tab.
         $this->derivatives["field_storage_$entity_type_id"] = array(
           'route_name' => "entity.field_config.{$entity_type_id}_storage_edit_form",